# -*- coding: utf-8 -*-

from django.conf import settings  # pylint: disable=W0611

from appconf import AppConf


class EasyMapsSettings(AppConf):
    CENTER = (-41.3, 32)
    GEOCODE = "easy_maps.geocode.google_v3"
    ZOOM = (
        16  # See https://developers.google.com/maps/documentation/javascript/tutorial#MapOptions for more information.
    )
    LANGUAGE = "en"  # See https://developers.google.com/maps/faq#languagesupport for supported languages.
    GOOGLE_KEY = None

    CACHE_LIFETIME = 600  # 10 minutes in seconds

    class Meta:
        prefix = "easy_maps"
        holder = "easy_maps.conf.settings"



# Generated by Django 2.1.7 on 2019-03-29 05:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("easy_maps", "0001_initial"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="address",
            name="geocode_error",
        ),
        migrations.AddField(
            model_name="address",
            name="exception",
            field=models.TextField(blank=True, verbose_name="has exception?"),
        ),
    ]



# -*- coding: utf-8 -*-

from django import forms
from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from .models import Address
from .widgets import AddressWithMapWidget


class HasExceptionFilter(admin.SimpleListFilter):
    title = _("exception")
    parameter_name = "has_exception"

    def lookups(self, request, model_admin):
        return (
            (1, _("Yes")),
            (0, _("No")),
        )

    def queryset(self, request, queryset):
        if self.value() is not None:
            ids = Address.objects.values_list("pk", flat=True)

            if self.value() == "1":
                return queryset.filter(pk__in=ids)

            elif self.value() == "0":
                return queryset.exclude(pk__in=ids)

        return queryset


class AddressAdmin(admin.ModelAdmin):
    list_display = ["address", "computed_address", "latitude", "longitude", "has_exception"]
    list_filter = [HasExceptionFilter]
    search_fields = ["address"]

    class form(forms.ModelForm):
        class Meta:
            widgets = {"address": AddressWithMapWidget({"class": "vTextField"})}



# Generated by Django 2.1.7 on 2019-03-29 07:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("easy_maps", "0002_auto_20190329_0541"),
    ]

    operations = [
        migrations.AddField(
            model_name="address",
            name="timestamp",
            field=models.DateTimeField(auto_now=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Address",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True)),
                ("address", models.CharField(unique=True, max_length=255, verbose_name="address")),
                (
                    "computed_address",
                    models.CharField(max_length=255, null=True, verbose_name="computed address", blank=True),
                ),
                ("latitude", models.FloatField(null=True, verbose_name="latitude", blank=True)),
                ("longitude", models.FloatField(null=True, verbose_name="longitude", blank=True)),
                ("geocode_error", models.BooleanField(default=False, verbose_name="geocode error")),
            ],
            options={
                "verbose_name": "EasyMaps Address",
                "verbose_name_plural": "Address Geocoding Cache",
            },
        ),
    ]
